package com.mcwl.web.controller.communityCenter;


import cn.hutool.core.bean.BeanUtil;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.communityCenter.domain.Community;
import com.mcwl.communityCenter.domain.dto.CommunityDto;
import com.mcwl.communityCenter.domain.vo.CommunityVo;
import com.mcwl.communityCenter.service.CommunityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 社区
 */
@Api(tags = "社区")
@RestController
@RequestMapping("community")
@RequiredArgsConstructor
public class CommunityController {

    private final CommunityService communityService;


    /**
     * 社区列表
     *
     * @return 社区列表
     */
    @ApiOperation(value = "社区列表")
    @PostMapping("list")
    public TableDataInfo getCommunityList(@RequestBody PageDomain pageDomain) {
        return communityService.listByPage(pageDomain);
    }


    /**
     * 添加社区
     *
     * @param communityDto 社区参数
     * @return 添加结果
     */
    @ApiOperation(value = "添加社区")
    @PostMapping("add")
    public AjaxResult addCommunity(@RequestBody CommunityDto communityDto) {
        Community community = new Community();
        BeanUtil.copyProperties(communityDto, community);
        communityService.save(community);
        return AjaxResult.success();
    }

    /**
     * 删除社区
     *
     * @param id 社区id
     * @return 删除结果
     */
    @ApiOperation(value = "删除社区")
    @PostMapping("delete")
    public AjaxResult deleteCommunity(@NotNull(message = "id不能为空")
                                   @ApiParam(value = "id", required = true)
                                   Long id) {
        communityService.removeById(id);
        return AjaxResult.success();
    }

}
